Date: 08 20, 2001 4:17:58 PM

# Moving Passes

Passes, whether they are a part of a stub region or not, can be moved around in the analyzer sequence.

To move a pass in the analyzer sequence:

1. In the Ana Tab, select the pass you want to move.

2. Click on the yellow up or down arrows on the Tab Toolbar, to move the pass to the desired location.

Note: Once the analyzer sequence has been changed, you will have to run the analyzer again for the change in the sequence to take. Passes in stub regions can only be moved around in the stub region. Once the order of the passes in the stub has been changed you must regenerate the rules before running the analyzer again. You can move a stub region by selecting the stub (either the start stub bead or the end of stub bead) and using the up and down arrows.